/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.gluten.qt.writer

import org.apache.gluten.qt.support.ResultVisitor.UnsupportedImpact

case class ImpactReport(operatorName: String, impact: UnsupportedImpact) extends Report {
  private val cumulativeCpuMs = impact.getCumulativeCpuDuration.toMillis
  private val count = impact.getCount
  private val sanitizedOperatorName = operatorName.replaceAll("[\r\n\t]+", " ").trim

  override def toTSVLine: String =
    Seq(s"$sanitizedOperatorName", s"$cumulativeCpuMs", s"$count").mkString("\t")
}
